@@ -118,11 +118,11 @@ class CombineItems(DSRequest):
 
         recordTarget = data.get('recordTarget')
         if not isinstance(recordTarget, dict):
-            raise Exception(f'recordTarget must be a dict')
+            raise Exception('recordTarget must be a dict')
 
         recordsSource = data.get('recordsSource')
         if not isinstance(recordsSource, list):
-            raise Exception(f'recordsSource must be a list')
+            raise Exception('recordsSource must be a list')
 
         # with transaction.atomic():
         CombineItems.combine(recordsSource=recordsSource, recordTarget=recordTarget)
