@@ -1,5 +1,4 @@
 import logging
-import uuid
 
 from django.db import transaction
 from django.db.models import PositiveIntegerField, CheckConstraint, Q, F
@@ -7,6 +6,7 @@ from django.forms import model_to_dict
 
 from isc_common import setAttr, delAttr
 from isc_common.bit import TurnBitOn
+from isc_common.common import uuid4
 from isc_common.common.functions import delete_dbl_spaces
 from isc_common.fields.code_field import CodeField
 from isc_common.fields.name_field import NameField
@@ -29,7 +29,7 @@ class Item_lineQuerySet(AuditQuerySet):
     def _check(self, **kwargs):
         if kwargs.get('parent') != None:
             if kwargs.get('parent' == kwargs.get('child')):
-                raise Exception(f'Attempt to write circular reference')
+                raise Exception('Attempt to write circular reference')
 
     def _checkDefaults(self, defaults):
         if defaults != None:
@@ -179,10 +179,10 @@ class Item_lineManager(TreeAuditModelManager):
         child_id = data.get('child_id')
 
         if parent_id == None:
-            raise Exception(f'parent_id is None')
+            raise Exception('parent_id == None')
 
         if child_id == None:
-            raise Exception(f'child_id is None')
+            raise Exception('child_id == None')
 
         with transaction.atomic():
 
@@ -217,7 +217,6 @@ class Item_lineManager(TreeAuditModelManager):
 
     def updateFromRequest(self, request, removed=None, function=None):
         request = DSRequest(request=request)
-        id = request.get_id()
         data = request.get_data()
         data_res = request.get_data()
         mode = data.get('mode')
@@ -226,12 +225,12 @@ class Item_lineManager(TreeAuditModelManager):
             dropRecords = data.get('dropRecords')
 
             if not dropRecords:
-                raise Exception(f'Не выбран источник замены.')
+                raise Exception('Не выбран источник замены.')
 
             targetRecord = data.get('targetRecord')
 
             if not targetRecord:
-                raise Exception(f'Не выбрана цель замены.')
+                raise Exception('Не выбрана цель замены.')
 
             dropRecord = dropRecords[0]
 
@@ -293,13 +292,55 @@ class Item_lineManager(TreeAuditModelManager):
         delAttr(data, 'mode')
         _data = dict()
 
+        params = dict()
         for key, val in data.items():
-            if str(key).find('__value_str') == -1 and str(key).find('__value_int') == -1:
+            if str(key).find('SPC_CLM_') != -1:
+                if str(key).find('_id') != -1:
+                    if val != None:
+                        setAttr(params, key, val)
+                elif str(key).find('__value_str') != -1:
+                    if val != None:
+                        setAttr(params, key, val)
+                elif str(key).find('__value_int') != -1:
+                    if val != None:
+                        setAttr(params, key, val)
+            else:
                 setAttr(_data, key, val)
 
         with transaction.atomic():
-            res = super().filter(id=id).update(**_data)
+            res_params=dict()
+            for key, val in params.items():
+                idx = str(key).find('_id')
+                if idx != -1:
+                    _key = str(key)[0:idx]
+                    param_str = params.get(f'{_key}__value_str')
+                    param_int = params.get(f'{_key}__value_int')
+
+                    if param_int != None:
+                        if StrToNumber(param_str) != param_int:
+                            param_str = str(param_int)
+
+                    attr, _ = Document_attributesManager.get_or_create_attribute(_key, param_str)
+                    setAttr(res_params, _key, attr)
+
             Item.objects.update_or_create(id=child_id, defaults=dict(props=item_props))
+            delAttr(_data, 'edizm__name')
+            delAttr(_data, 'section')
+            delAttr(_data, 'section_num')
+            delAttr(_data, 'subsection')
+            delAttr(_data, 'lastmodified')
+            delAttr(_data, 'editing')
+            delAttr(_data, 'deliting')
+            delAttr(_data, 'id')
+            delAttr(_data, 'parent_id')
+            delAttr(_data, 'child_id')
+
+            child = Item.objects.get(id=data.get('child_id'))
+            parent = Item.objects.get(id=data.get('parent_id'))
+
+            res_params.update(_data)
+            updated = Item_line.objects.filter(child=child, parent=parent).update(**res_params)
+            logger.debug(f'updated: {updated}')
         return data_res
 
     def copyFromRequest(self, request, removed=None, ):
@@ -311,13 +352,13 @@ class Item_lineManager(TreeAuditModelManager):
         res = None
         with managed_progress(
                 qty=len(data.get('records')),
-                id=str(uuid.uuid4()),
+                id=uuid4(),
                 user=request.user,
                 title="Выполнено",
                 props=TurnBitOn(0, 0)
         ) as progress:
             with transaction.atomic():
-                progress.setContentsLabel(f'<b>Создание строк детализации</b>')
+                progress.setContentsLabel('<b>Создание строк детализации</b>')
                 for record in data.get('records'):
                     if record.get("parent_id") == None:
                         raise Exception('Верхний уровень не подлежит внесению в детализацию.')
@@ -395,7 +436,9 @@ class Item_lineManager(TreeAuditModelManager):
         with transaction.atomic():
             for id, mode in request.get_tuple_ids():
                 if mode == 'hide':
-                    ...
+                    pass
+                elif mode == 'visible':
+                    pass
                 else:
                     for item_line in super().filter(id=id).select_for_update():
                         Item_refs.objects1.filter(parent=item_line.parent, child=item_line.child).delete_with_checked()
@@ -420,7 +463,7 @@ class Item_line(AuditModel):
     SPC_CLM_USER = ForeignKeyProtect(Document_attributes, verbose_name='Пользовательская', related_name='Item_line_SPC_CLM_USER', null=True, blank=True)
     SPC_CLM_KOD = ForeignKeyProtect(Document_attributes, verbose_name='Код', related_name='Item_line_SPC_CLM_KOD', null=True, blank=True)
     SPC_CLM_FACTORY = ForeignKeyProtect(Document_attributes, verbose_name='Предприятие - изготовитель', related_name='Item_line_SPC_CLM_FACTORY', null=True, blank=True)
-    edizm = ForeignKeyProtect(Ed_izm, verbose_name='Еденица измерения', related_name='Item_line_EdIzm', null=True, blank=True)
+    edizm = ForeignKeyProtect(Ed_izm, verbose_name='Единица измерения', related_name='Item_line_EdIzm', null=True, blank=True)
     section = CodeField()
     section_num = PositiveIntegerField(null=True, blank=True)
     subsection = NameField()
@@ -443,6 +486,7 @@ class Item_line(AuditModel):
 
     def __str__(self):
         return f'\nparent: [{self.parent}]\n' \
+               f'\nchild: [{self.child}]\n' \
                f'\nSPC_CLM_FORMAT: [{self.SPC_CLM_FORMAT}]' \
                f'\nSPC_CLM_ZONE: [{self.SPC_CLM_ZONE}]' \
                f'\nSPC_CLM_POS: [{self.SPC_CLM_POS}]' \
