@@ -1,6 +1,7 @@
 import logging
 
 from django.conf import settings
+from django.core.exceptions import EmptyResultSet
 from django.db import transaction
 from django.db.models import BigIntegerField, BooleanField, PositiveIntegerField
 from django.forms import model_to_dict
@@ -12,7 +13,7 @@ from isc_common.fields.related import ForeignKeyProtect
 from isc_common.http.DSRequest import DSRequest
 from isc_common.models.base_ref import Hierarcy
 from isc_common.models.tree_audit import TreeAuditModelManager, TreeAuditModelQuerySet
-from isc_common.number import DelProps
+from isc_common.number import DelProps, ToDecimal, ToStr
 from kaf_pas.ckk.models.item import Item_add, Item
 from kaf_pas.ckk.models.item_line import Item_lineManager
 from kaf_pas.ckk.models.item_refs import Item_refsManager
@@ -24,11 +25,37 @@ logger = logging.getLogger(__name__)
 
 
 class Item_viewQuerySet(TreeAuditModelQuerySet):
+    def get_range_rows_variant(self, request, function=None, distinct_field_names=None, remove_fields=None):
+        request = DSRequest(request=request)
+
+        self.alive_only = request.alive_only
+        self.enabledAll = request.enabledAll
+        data = request.get_data()
+        ts = data.get('ts')
+        parent_id = data.get('parent_id')
+        logger.debug(f'data in : {data}')
+        data = dict(ts=ts, parent_id=parent_id)
+        logger.debug(f'data out : {data}')
+        request.set_data(data)
+        res = self.get_range_rows(
+            start=request.startRow,
+            end=request.endRow,
+            function=function,
+            distinct_field_names=distinct_field_names,
+            json=request.json,
+            criteria=request.get_criteria(),
+            user=request.user
+        )
+        return res
+
     def get_range_rows(self, start=None, end=None, function=None, json=None, distinct_field_names=None, criteria=None, user=None, *args):
         json = self.rearrange_parent(json=json)
 
         queryResult = self._get_range_rows(*args, start=start, end=end, function=function, json=json, distinct_field_names=distinct_field_names)
-        logger.debug(f'\n\n{queryResult.query}\n')
+        try:
+            logger.debug(f'\n\n{queryResult.query}\n')
+        except EmptyResultSet as ex:
+            logger.warning(ex)
 
         if function:
             res = [function(record) for record in queryResult]
@@ -38,10 +65,6 @@ class Item_viewQuerySet(TreeAuditModelQuerySet):
         return res
 
 
-def filter(self, *args, **kwargs):
-    return super().filter(*args, **kwargs)
-
-
 class Item_viewManager(TreeAuditModelManager):
 
     def updateFromRequest(self, request, removed=None, function=None):
@@ -98,9 +121,9 @@ class Item_viewManager(TreeAuditModelManager):
         res = {
             "id": record.id,
             "STMP_1_id": record.STMP_1.id if record.STMP_1 else None,
-            "STMP_1__value_str": record.STMP_1.value_str if record.STMP_1 else None,
+            "STMP_1__value_str": ToStr(record.STMP_1.value_str) if record.STMP_1 else None,
             "STMP_2_id": record.STMP_2.id if record.STMP_2 else None,
-            "STMP_2__value_str": record.STMP_2.value_str if record.STMP_2 else None,
+            "STMP_2__value_str": ToStr(record.STMP_2.value_str) if record.STMP_2 else None,
             "lastmodified": record.lastmodified,
             "document_id": record.document.id if record.document else None,
             "lotsman_document_id": record.lotsman_document.id if record.lotsman_document else None,
@@ -115,6 +138,7 @@ class Item_viewManager(TreeAuditModelManager):
             "version": record.version,
             "where_from": record.where_from,
             "isLotsman": record.isLotsman,
+            "qty_operations": record.qty_operations,
             "props": record.props,
             "refs_props": record.refs_props,
             'icon': Item_lineManager.getIcon(record)
@@ -132,7 +156,7 @@ class Item_viewManager(TreeAuditModelManager):
         from kaf_pas.ckk.models.item_image_refs import Item_image_refs
 
         if not isinstance(item, Item_view) and not isinstance(item, Item):
-            raise Exception(f'item must be a Item type')
+            raise Exception('item must be a Item type')
 
         key = 'Item_viewManager.copy_item'
         settings.LOCKS.acquire(key)
@@ -230,6 +254,7 @@ class Item_view(Hierarcy):
     refs_props = Item_refsManager.props()
     version = PositiveIntegerField(null=True, blank=True)
     section = CodeField(null=True, blank=True)
+    qty_operations = PositiveIntegerField()
 
     isFolder = BooleanField()
 
