@@ -18,8 +18,7 @@ logger = logging.getLogger(__name__)
 
 
 class MaterialsQuerySet(BaseRefQuerySet, CommonManagetWithLookUpFieldsQuerySet):
-    def filter(self, *args, **kwargs):
-        return super().filter(*args, **kwargs)
+    pass
 
 
 class MaterialsManager(BaseRefManager, CommonManagetWithLookUpFieldsManager):
@@ -82,9 +81,9 @@ class MaterialsManager(BaseRefManager, CommonManagetWithLookUpFieldsManager):
 
         res = super().create(**_data)
         res = model_to_dict(res)
-        props = res.get( 'props')
+        props = res.get('props')
         if props and isinstance(props, BitHandler):
-            props = res.get( 'props')._value
+            props = res.get('props')._value
             setAttr(res, 'props', props)
         data.update(res)
         return data
@@ -122,9 +121,9 @@ class MaterialsManager(BaseRefManager, CommonManagetWithLookUpFieldsManager):
 
         res, created = super().filter(id=data.get('id')).update(**_data)
         res = model_to_dict(res)
-        props = res.get( 'props')
+        props = res.get('props')
         if props and isinstance(props, BitHandler):
-            props = res.get( 'props')._value
+            props = res.get('props')._value
             setAttr(res, 'props', props)
         data.update(res)
         return data
