@@ -8,6 +8,9 @@ class GridCoonstant:
     refresh_production_order_item_grid = "refresh_production_order_item_grid"
     refresh_production_order_item_grid_row = "refresh_production_order_item_gridRow"
 
+    refresh_production_operations_grid = "refresh_production_operations_grid"
+    refresh_production_operations_grid_row = "refresh_production_operations_grid_grid_row"
+
     refresh_production_order_operationsValues_grid = "refresh_production_order_operationsValues_grid"
     refresh_production_order_operationsValues_grid_row = "refresh_production_order_operationsValues_grid_row"
 
@@ -16,3 +19,5 @@ class GridCoonstant:
 
     refresh_production_buffers_grid = "refresh_production_buffers_grid"
     refresh_production_buffers_grid_row = "refresh_production_buffers_grid_row"
+
+    lock_insert_update_delete_function_of_table = "lock_insert_update_delete_function_of_table"
