@@ -1,6 +1,6 @@
 from django.urls import path
 
-from kaf_pas.common.views import calendarGraph, jasperReport
+from kaf_pas.common.views import jasperReport
 
 urlpatterns = [
 
