@@ -2,9 +2,10 @@ import logging
 
 from django.core.management import BaseCommand
 from django.db import transaction
-from isc_common.logger.Logger import Logger
 from tqdm import tqdm
 
+from isc_common.auth.models.user import User
+from isc_common.logger.Logger import Logger
 from kaf_pas.kd.models.cdws import Cdws
 from kaf_pas.kd.models.documents import Documents
 from kaf_pas.kd.models.documents_ext import DocumentManagerExt
@@ -23,6 +24,6 @@ class Command(BaseCommand):
         with transaction.atomic():
             pbar = tqdm(total=len(cdws))
             for document in cdws:
-                self.documentManagerExt.make_cdw(document=document)
+                self.documentManagerExt.make_cdw(document=document, user=User.objects.get(id=2))
                 pbar.update()
         pbar.close()
