@@ -142,7 +142,7 @@ class DocumentManager(CommonManagetWithLookUpFieldsManager):
         attr_type = kwargs.get('attr_type')
         file_document = kwargs.get('file_document')
         path = kwargs.get('path')
-        for_delete=None
+        for_delete = None
 
         if virt_path:
             if virt_path[0:1] == os.sep or virt_path[0:1] == os.altsep:
@@ -189,7 +189,7 @@ class DocumentManager(CommonManagetWithLookUpFieldsManager):
                     if Lotsman_documents_hierarcy.objects.filter(document=doc).count() > 0:
                         return doc, False
                     else:
-                        for_delete=doc.id
+                        for_delete = doc.id
 
             Uploades_documents.objects.filter(document_id=for_delete).delete()
             Documents.objects.filter(id=for_delete).delete()
@@ -231,9 +231,9 @@ class DocumentManager(CommonManagetWithLookUpFieldsManager):
         from kaf_pas.kd.models.documents_history import Documents_history
 
         if not isinstance(user, User):
-            raise Exception(f'user  must be a User instance.')
+            raise Exception('user  must be a User instance.')
 
-        key='DocumentManager.delete'
+        key = 'DocumentManager.delete'
         settings.LOCKS.acquire(key)
         res = 0
         lotsman_res = 0
