@@ -129,9 +129,6 @@ class DocumentManagerExt:
                                         )
 
                                         try:
-                                            document_attr_cross = Document_attr_cross.objects.filter(
-                                                attribute=document_attribute,
-                                                document=document)[0]
                                             setAttr(line_specification, 'SPC_CLM_MARK_ID', _document_attribute.id)
                                         except IndexError:
                                             Document_attr_cross.objects.create(
