@@ -26,7 +26,7 @@ class Documents_thumbManager(CryptoManager):
                                     path
                                 from
                                     kd_documents_{table_name}
-                                where {doc_type}_id is not null        
+                                where {doc_type}_id is not null
                                 group by
                                     {doc_type}_id,
                                     path
@@ -86,6 +86,8 @@ class Documents_thumbManager(CryptoManager):
                         item.soft_delete()
                         Documents_thumb10.objects.filter(path=item.path).soft_delete()
                         res += 1
+                elif mode == 'visible':
+                    super().filter(id=id).soft_restore()
                 else:
                     for item in super().filter(id=id):
                         item.delete()
@@ -108,7 +110,7 @@ class Documents_thumb(Crypto_file):
     objects = Documents_thumbManager()
 
     def __str__(self):
-        return f"{self.id}"
+        return f"{self.document}"
 
     class Meta:
         verbose_name = 'JPEG варианты документов уменьшенная копия'
