@@ -1,7 +1,6 @@
 import logging
 
 from bitfield import BitField
-from django.conf import settings
 from django.db.models import TextField, PositiveIntegerField, DateTimeField, BigAutoField, BooleanField, Model
 from django.utils import timezone
 
@@ -34,7 +33,7 @@ class Document_viewQuerySet(DocumentQuerySet):
 
     def get_info(self, request, *args):
         request = DSRequest(request=request)
-        request=self._append_item_documents(request=request)
+        request = self._append_item_documents(request=request)
         criteria = self.get_criteria(json=request.json)
         cnt = super().filter(*args, criteria).count()
         cnt_all = super().filter().count()
