@@ -43,7 +43,7 @@ class Lotsman_documents_hierarcyManagerExt:
             )
 
             item_refs, _ = Item_refs.objects.get_or_create(child=top_item)
-            if  item_refs.parent != None:
+            if item_refs.parent != None:
                 item_refs.delete()
                 item_refs, _ = Item_refs.objects.get_or_create(child=top_item)
 
@@ -85,7 +85,7 @@ class Lotsman_documents_hierarcyManagerExt:
                         break
 
             parent_str = f'''parent_id ={lotsman_documents_hierarcy_view_record.id}'''
-            props_str = f'props in (1, 3)'
+            props_str = 'props in (1, 3)'
 
             sql_str = f'''WITH RECURSIVE r AS (
                                SELECT *, 1 AS level
@@ -137,7 +137,7 @@ class Lotsman_documents_hierarcyManagerExt:
                                     except Lotsman_documents_hierarcy_view.DoesNotExist as ex:
                                         raise ex
                                     except Lotsman_documents_hierarcy_view.MultipleObjectsReturned:
-                                        _lotsman_documents_hierarcy = Lotsman_documents_hierarcy_view.objects.filter(id=lotsman_documents_hierarcy.parent_id).distinct('id')[0]
+                                        _lotsman_documents_hierarcy = Lotsman_documents_hierarcy_view.objects.filter(id=lotsman_documents_hierarcy.parent_id).filter()[0]
 
                                     parent, created2 = self.get_item(
                                         lotsman_documents_hierarcy=_lotsman_documents_hierarcy,
@@ -224,8 +224,8 @@ class Lotsman_documents_hierarcyManagerExt:
 
                             for lotsman_documents_hierarcy in Lotsman_documents_hierarcy_view.objects.raw(f'''select * from {mat_view_name} where props=1 and attr_name=%s order by level''', ['''Чертеж''']):
 
-                                assmbl_progress.setContentsLabel(f'''<h3>Привязка чертежей. ({lotsman_documents_hierarcy.SPC_CLM_NAME.value_str if lotsman_documents_hierarcy.SPC_CLM_NAME else ''} : 
-                                                                                                {lotsman_documents_hierarcy.SPC_CLM_MARK.value_str if lotsman_documents_hierarcy.SPC_CLM_MARK else ''})</h3>''')
+                                assmbl_progress.setContentsLabel(f'''<h3>Привязка чертежей. ({lotsman_documents_hierarcy.SPC_CLM_NAME.value_str if lotsman_documents_hierarcy.SPC_CLM_NAME else ''} :
+                                                                                            {lotsman_documents_hierarcy.SPC_CLM_MARK.value_str if lotsman_documents_hierarcy.SPC_CLM_MARK else ''})</h3>''')
                                 item, _ = self.get_item(
                                     lotsman_documents_hierarcy=lotsman_documents_hierarcy,
                                     items_pairs=items_pairs,
@@ -273,7 +273,7 @@ class Lotsman_documents_hierarcyManagerExt:
 
             # FOR DEBUG
             with connection.cursor() as cursor:
-                cursor.execute(f'''select count(*) from kd_lotsman_documents_hierarcy where props=1''')
+                cursor.execute('''select count(*) from kd_lotsman_documents_hierarcy where props=1''')
                 count, = cursor.fetchone()
             # END FOR DEBUG
 
@@ -289,7 +289,7 @@ class Lotsman_documents_hierarcyManagerExt:
         from kaf_pas.ckk.models.item_line import Item_lineManager
 
         if not isinstance(parent, Item):
-            raise Exception(f'item mut be Item instnce.')
+            raise Exception('item mut be Item instnce.')
 
         with connection.cursor() as cursor:
             cursor.execute(f'select count(*) from {mat_view_name} where parent_id=%s', [parent.lotsman_document.id])
@@ -408,7 +408,7 @@ class Lotsman_documents_hierarcyManagerExt:
         elif len(items) == 1:
             return items[0], False
         else:
-            raise Exception(f'Неоднозначный выбор.')
+            raise Exception('Неоднозначный выбор.')
 
     def make_mview(self):
         from kaf_pas.system.models.contants import Contants
@@ -465,13 +465,13 @@ class Lotsman_documents_hierarcyManagerExt:
                                                                                                  from kd_lotsman_documents_hierarcy_refs hr                                                            	
                                                                                                  where hr.parent_id = lts.id) > 0 THEN true
                                                                                            ELSE false
-                                                                                      END AS "isFolder",                                                                                 
-                                                                                      ltsr.section, 
+                                                                                      END AS "isFolder",                                                                  
+                                                                                      ltsr.section,
                                                                                       ltsr.subsection,
                                                                                       att.code attr_code,
                                                                                       att.name attr_name
                                                                                       $COMMA
-                                                                                      $FIELDS     
+                                                                                      $FIELDS
                                                                                FROM kd_lotsman_documents_hierarcy lts
                                                                                        join kd_lotsman_documents_hierarcy_refs ltsr on ltsr.child_id = lts.id
                                                                                        join ckk_attr_type att on att.id = lts.attr_type_id WITH DATA;
@@ -502,18 +502,21 @@ class Lotsman_documents_hierarcyManagerExt:
             # self.logger.logging(f'{m_view_name} recreated')
 
             sql_array = []
-            sql_array.append(f'''CREATE VIEW {m_view_recurs_name} AS select * from (WITH RECURSIVE r AS (
-                                       SELECT *, 1 AS level
-                                       FROM {m_view_name}
-                                       WHERE parent_id IS NULL
-
-                                       union all
-
-                                       SELECT {m_view_name}.*, r.level + 1 AS level
-                                       FROM {m_view_name}
-                                                JOIN r
-                                                     ON {m_view_name}.parent_id = r.id)                                
-                                   select * from r order by level) as a''')
+            sql_array.append(
+                f'''CREATE VIEW {m_view_recurs_name} AS
+                                                        select *
+                                                        from (WITH RECURSIVE r AS (
+                                                            SELECT *, 1 AS level
+                                                            FROM {m_view_name}
+                                                            WHERE parent_id IS NULL                                                        
+                                                            union all
+                                                            SELECT {m_view_name}.*, r.level + 1 AS level
+                                                            FROM {m_view_name}
+                                                                     JOIN r ON {m_view_name}.parent_id = r.id)
+                                                              select *
+                                                              from r
+                                                              order by level) as a'''
+            )
             sql_str = ';\n'.join(sql_array)
             # self.logger.logging(f'\n{sql_str}')
             cursor.execute(sql_str)
