@@ -1,23 +1,22 @@
 import logging
 
-from django.contrib.postgres.fields import JSONField
-from django.db.models import TextField, PositiveIntegerField
+from django.db.models import TextField
 
 from isc_common import delAttr
+from isc_common.fields.code_field import JSONFieldIVC
 from isc_common.fields.related import ForeignKeyCascade
 from isc_common.http.DSRequest import DSRequest
-from isc_common.models.audit import AuditModel, AuditManager, AuditQuerySet
+from isc_common.models.audit import AuditModel, AuditManager
 from kaf_pas.ckk.models.item import Item
+from kaf_pas.planing.models.operations import BaseOperationQuerySet
 from kaf_pas.production.models.launches import Launches
 
 logger = logging.getLogger(__name__)
 
 
-class Operation_item_addQuerySet(AuditQuerySet):
+class Operation_item_addQuerySet(BaseOperationQuerySet):
     def get_range_rows1(self, request, function=None, distinct_field_names=None, remove_fields=None):
         request = DSRequest(request=request)
-        data = request.get_data()
-
         delAttr(request.json.get('data'), 'level_id')
 
         self.alive_only = request.alive_only
@@ -25,6 +24,7 @@ class Operation_item_addQuerySet(AuditQuerySet):
         res = self.get_range_rows(start=request.startRow, end=request.endRow, function=function, distinct_field_names=distinct_field_names, json=request.json, criteria=request.get_criteria())
         return res
 
+
 class Operation_item_addManager(AuditManager):
 
     @staticmethod
@@ -45,7 +45,7 @@ class Operation_item_add(AuditModel):
     item = ForeignKeyCascade(Item)
     launch = ForeignKeyCascade(Launches)
     item_full_name = TextField(db_index=True)
-    item_full_name_obj = JSONField(default=dict)
+    item_full_name_obj = JSONFieldIVC(default=dict)
 
     objects = Operation_item_addManager()
 
