@@ -1,15 +1,14 @@
 import logging
 
 from isc_common.fields.related import ForeignKeyCascade
-from isc_common.models.audit import AuditModel, AuditManager, AuditQuerySet
-from kaf_pas.planing.models.operation_refs import Operation_refs
-from kaf_pas.planing.models.operations import Operations
+from isc_common.models.audit import AuditModel, AuditManager
+from kaf_pas.planing.models.operations import Operations, BaseOperationQuerySet
 from kaf_pas.production.models.launch_operations_item import Launch_operations_item
 
 logger = logging.getLogger(__name__)
 
 
-class Operation_launch_itemQuerySet(AuditQuerySet):
+class Operation_launch_itemQuerySet(BaseOperationQuerySet):
     pass
 
 
