@@ -1,20 +1,16 @@
 import logging
 
-from isc_common import setAttr
 from isc_common.fields.related import ForeignKeyCascade, ForeignKeyProtect
-from isc_common.http.DSRequest import DSRequest
-from isc_common.models.audit import AuditModel, AuditManager, AuditQuerySet
-from isc_common.number import DelProps
-from kaf_pas.planing.models.operations import Operations, OperationsManager
+from isc_common.models.audit import AuditModel, AuditManager
+from kaf_pas.planing.models.operations import Operations, BaseOperationQuerySet
 from kaf_pas.production.models.launches import Launches
 
 logger = logging.getLogger(__name__)
 
 
-class Operation_launchesQuerySet(AuditQuerySet):
+class Operation_launchesQuerySet(BaseOperationQuerySet):
     pass
 
-
 class Operation_launchesManager(AuditManager):
 
     @staticmethod
