@@ -3,23 +3,65 @@ import logging
 from bitfield import BitField
 from django.db.models import CheckConstraint, Q, F, UniqueConstraint
 
-from isc_common import delAttr1, setAttr
+from isc_common import Wrapper, delAttr
 from isc_common.fields.related import ForeignKeyProtect
 from isc_common.models.audit import AuditModel
 from isc_common.models.tree_audit import TreeAuditModelManager, TreeAuditModelQuerySet
-from kaf_pas.planing.models.operations import Operations
+from kaf_pas.planing.models.operations import Operations, BaseOperationQuerySet
 
 logger = logging.getLogger(__name__)
 
 
+class ORF_Wrapper(Wrapper):
+    parent = None
+    child = None
+    parent_id = None
+    child_id = None
+
+
 class Operation_refsQuerySet(TreeAuditModelQuerySet):
+    def create(self, **kwargs):
+        refs = ORF_Wrapper(**kwargs)
+
+        if not kwargs.get('enable_parent_None'):
+            if refs.parent == None and refs.parent_id == None:
+                raise Exception('Запись parent == None Запрещена')
+        else:
+            delAttr(kwargs, 'enable_parent_None')
+
+        return super().create(**kwargs)
+
     def delete(self):
         self.check_dliting = False
 
         return super().delete()
 
+
 class Operation_refsManager(TreeAuditModelManager):
 
+    def delete_m2m(self, operation_refs, props=None):
+        if not isinstance(operation_refs, Operation_refs):
+            raise Exception(f'element: {operation_refs} must be Operation_refs')
+
+        logger.debug('\noperation_refs: ==================================================')
+        logger.debug(f'operation_refs: {operation_refs}')
+        logger.debug('operation_refs: ==================================================\n')
+
+        if props != None:
+            query = Operation_refs.objects.filter(child=operation_refs.parent, props=props)
+        else:
+            query = Operation_refs.objects.filter(child=operation_refs.parent)
+
+        for childs_refs in query:
+            logger.debug('\nchilds_refs: ==================================================')
+            logger.debug(f'childs_refs: {childs_refs}')
+            logger.debug('childs_refs: ==================================================\n')
+            childs_refs.child = operation_refs.child
+            childs_refs.save()
+
+        deleted = operation_refs.delete()
+        logger.debug(f'\ndeleted: {deleted}')
+
     @staticmethod
     def props():
         return BitField(flags=(
@@ -27,7 +69,7 @@ class Operation_refsManager(TreeAuditModelManager):
             ('outer_routing', 'Связь операций между товарными позициями'),  # 1-2
             ('product_order_routing', 'Связи в блоке задания на производство'),  # 2-4
             ('product_making', 'Связи выпуска'),  # 3-8
-            ('product_making_block', 'Блок операций выпуска, удаляется как одно целое для правильного удаления релизов'),  # 4-16
+            # ('product_making_block', 'Блок операций выпуска, удаляется как одно целое для правильного удаления релизов'),  # 4-16
         ), default=0, db_index=True)
 
     @staticmethod
@@ -52,8 +94,9 @@ class Operation_refs(AuditModel):
     objects = Operation_refsManager()
 
     def __str__(self):
-        return f"ID:{self.id},\n " \
-               f"child: [{self.child}],\n " \
+        return f"\n\nID:{self.id},\n\n " \
+               f"props:{self.props},\n\n " \
+               f"child: [{self.child}],\n\n " \
                f"parent: [{self.parent}]"
 
     def __repr__(self):
