@@ -3,15 +3,14 @@ import logging
 from bitfield import BitField
 
 from isc_common.fields.related import ForeignKeyCascade
-from isc_common.models.audit import AuditModel, AuditManager, AuditQuerySet
-from kaf_pas.planing.models.levels import Levels
-from kaf_pas.planing.models.operations import Operations
+from isc_common.models.audit import AuditModel, AuditManager
+from kaf_pas.planing.models.operations import Operations, BaseOperationQuerySet
 from kaf_pas.planing.models.sections import Sections
 
 logger = logging.getLogger(__name__)
 
 
-class Operation_sectionQuerySet(AuditQuerySet):
+class Operation_sectionQuerySet(BaseOperationQuerySet):
     pass
 
 
@@ -40,7 +39,6 @@ class Operation_section(AuditModel):
     operation = ForeignKeyCascade(Operations)
     section = ForeignKeyCascade(Sections)
 
-
     objects = Operation_sectionManager()
 
     def __str__(self):
