@@ -1,6 +1,7 @@
 import logging
 
-from isc_common import Stack, NotImplement
+from isc_common import Stack
+from isc_common.common import new
 
 logger = logging.getLogger(__name__)
 
@@ -82,8 +83,8 @@ class Routing_ext:
                 ],
                 level_id=level_id
             ).
-                values('location_id', 'location__name').
-                distinct()
+            values('location_id', 'location__name').
+            distinct()
         ],
             key=lambda x: x['title'])
 
@@ -100,7 +101,7 @@ class Routing_ext:
                 prompt=f'''ID: {operation.get('resource_id')}, {operation.get('resource__description')}''',
             )
             for operation in Operation_resources_view.objects.
-                filter(
+            filter(
                 launch_id=launch_id,
                 level_id=level_id,
                 location_id=location_id,
@@ -108,9 +109,7 @@ class Routing_ext:
                     Operations_view.props.inner_routing,
                     Operations_view.props.outer_routing,
                 ],
-            ).
-                values('resource_id', 'resource__name', 'resource__description').
-                distinct()
+            ).values('resource_id', 'resource__name', 'resource__description').distinct()
         ],
             key=lambda x: x['title'])
 
@@ -133,7 +132,6 @@ class Routing_ext:
         from isc_common.progress import managed_progress
         from isc_common.progress import progress_deleted
         from isc_common.progress import ProgressDroped
-        from isc_common.ws.webSocket import WebSocket
         from kaf_pas.planing.models.levels import Levels
         from kaf_pas.planing.models.operation_item import Operation_item
         from kaf_pas.planing.models.operation_item_add import Operation_item_add
@@ -150,24 +148,30 @@ class Routing_ext:
         from kaf_pas.production.models.launch_operation_resources import Launch_operation_resources
         from kaf_pas.production.models.launch_operations_item import Launch_operations_item
         from kaf_pas.production.models.launches import Launches
-        from kaf_pas.production.models.launches import LaunchesManager
+        from kaf_pas.ckk.models.ed_izm import Ed_izm
+        from kaf_pas.production.models.launches_view import Launches_viewManager
 
         logger.debug(f'data: {data}')
 
         launch_ids = []
         launches_head = []
 
+        edizm_shtuka = Ed_izm.objects.get(code='шт')
+
         for launch_id in data.get('data'):
-            l = Launches.objects.filter(parent_id=launch_id)
-            if l.count() > 0:
-                launch_ids.extend([item.id for item in l])
+            launches = Launches.objects.filter(parent_id=launch_id)
+            if launches.count() > 0:
+                launch_ids.extend([item.id for item in launches])
                 launches_head.append(Launches.objects.get(id=launch_id))
             else:
                 launch_ids.extend([item.id for item in Launches.objects.filter(id=launch_id)])
 
         user = data.get('user')
         if not isinstance(user, User):
-            raise Exception(f'user must be User instance.')
+            raise Exception('user must be User instance.')
+
+        if len(launch_ids) == 0:
+            raise Exception('Нет входных данных.')
 
         launch_qty = Launches.objects.filter(id__in=launch_ids).count()
 
@@ -182,77 +186,77 @@ class Routing_ext:
             key = f'OperationsManager.make_routing_{launch.id}'
             settings.LOCKS.acquire(key)
             sql_str = f'''with a as (
-                                                    with recursive r as (
-                                                        select *,
-                                                               1 as level
-                                                        from production_launch_item_refs
-                                                        where parent_id is null
-                                                           and launch_id = {launch.id}
-                                                           and is_bit_on(props,0) = true
-                                                        union all
-                                                        select production_launch_item_refs.*,
-                                                               r.level + 1 as level
-                                                        from production_launch_item_refs
-                                                                 join r
-                                                                      on
-                                                                          production_launch_item_refs.parent_id = r.child_id
-                                                        where is_bit_on(r.props::int,0) = true
-                                                        and is_bit_on(production_launch_item_refs.props,0) = true
-                                                    )
+                                        with recursive r as (
+                                            select *,
+                                                   1 as level
+                                            from production_launch_item_refs
+                                            where parent_id is null
+                                               and launch_id = {launch.id}
+                                               and is_bit_on(props,0) = true
+                                            union all
+                                            select production_launch_item_refs.*,
+                                                   r.level + 1 as level
+                                            from production_launch_item_refs
+                                                     join r
+                                                          on
+                                                              production_launch_item_refs.parent_id = r.child_id
+                                            where is_bit_on(r.props::int,0) = true
+                                            and is_bit_on(production_launch_item_refs.props,0) = true
+                                        )
 
-                                                    select r1.id,
-                                                           r1.parent_id,
-                                                           r1.child_id,
-                                                           r1.launch_id,
-                                                           r1.qty,
-                                                           r1.replication_factor,
-                                                           r1.qty_per_one,
-                                                           r1.edizm,
-                                                           r1.level,
-                                                           r1.item_full_name,
-                                                           r1.item_full_name_obj                 
-                                                    from (select distinct r.id,
-                                                                          r.parent_id,
-                                                                          r.child_id,
-                                                                          r.launch_id,
-                                                                          r.item_full_name,
-                                                                          r.item_full_name_obj,
-                                                                          r.qty,
-                                                                          r.replication_factor,
-                                                                          r.qty_per_one,  
-                                                                          (
-                                                                              select plil.section
-                                                                              from production_launch_item_line plil
-                                                                              where plil.child_id = r.child_id
-                                                                                and plil.parent_id = r.parent_id
-                                                                                and plil.launch_id = r.launch_id) section,
-                                                                          (
-                                                                              select plil.edizm_id
-                                                                              from production_launch_item_line plil
-                                                                              where plil.child_id = r.child_id
-                                                                                and plil.parent_id = r.parent_id
-                                                                                and plil.launch_id = r.launch_id) edizm,  
-                                                                          level
-                                                          from r
-                                                                   join ckk_item ci on ci.id = r.child_id
-                                                          where r.launch_id = {launch.id}
-                                                          order by level desc) r1
-                                                    where lower(r1.section) != 'документация'
-                                                       or r1.parent_id is null
-                                                )
+                                        select r1.id,
+                                               r1.parent_id,
+                                               r1.child_id,
+                                               r1.launch_id,
+                                               r1.qty,
+                                               r1.replication_factor,
+                                               r1.qty_per_one,
+                                               r1.edizm,
+                                               r1.level,
+                                               r1.item_full_name,
+                                               r1.item_full_name_obj
+                                        from (select distinct r.id,
+                                                              r.parent_id,
+                                                              r.child_id,
+                                                              r.launch_id,
+                                                              r.item_full_name,
+                                                              r.item_full_name_obj,
+                                                              r.qty,
+                                                              r.replication_factor,
+                                                              r.qty_per_one,
+                                                              (
+                                                                  select plil.section
+                                                                  from production_launch_item_line plil
+                                                                  where plil.child_id = r.child_id
+                                                                    and plil.parent_id = r.parent_id
+                                                                    and plil.launch_id = r.launch_id) section,
+                                                              (
+                                                                  select plil.edizm_id
+                                                                  from production_launch_item_line plil
+                                                                  where plil.child_id = r.child_id
+                                                                    and plil.parent_id = r.parent_id
+                                                                    and plil.launch_id = r.launch_id) edizm,
+                                                              level
+                                              from r
+                                                       join ckk_item ci on ci.id = r.child_id
+                                              where r.launch_id = {launch.id}
+                                              order by level desc) r1
+                                        where lower(r1.section) != 'документация'
+                                           or r1.parent_id is null
+                                    )
 
-                                                select a.id,
-                                                       a.parent_id,
-                                                       a.child_id,
-                                                       a.launch_id,
-                                                       a.qty,
-                                                       a.replication_factor,
-                                                       a.qty_per_one,
-                                                       a.edizm,
-                                                       a.level,
-                                                       a.item_full_name,
-                                                       a.item_full_name_obj
-                                                from a '''
+                                    select a.id,
+                                           a.parent_id,
+                                           a.child_id,
+                                           a.launch_id,
+                                           a.qty,
+                                           a.replication_factor,
+                                           a.qty_per_one,
+                                           a.edizm,
+                                           a.level,
+                                           a.item_full_name,
+                                           a.item_full_name_obj
+                                    from a '''
 
             mat_view_name = create_tmp_mat_view(sql_str=sql_str, indexes=['parent_id', 'child_id'])
             with connection.cursor() as cursor:
@@ -330,7 +334,7 @@ class Routing_ext:
                                             outcome_operation = Operations.objects.create(
                                                 date=datetime.now(),
                                                 opertype=settings.OPERS_TYPES_STACK.ROUTING_TASK,
-                                                status=settings.OPERS_TYPES_STACK.ROUTING_TASK_STATUSES.get('new'),
+                                                status=settings.OPERS_TYPES_STACK.ROUTING_TASK_STATUSES.get(new),
                                                 creator=user
                                             )
                                             logger.debug(f'Created outcome_operation :  {outcome_operation}')
@@ -357,6 +361,7 @@ class Routing_ext:
                                                 num=launch_operations_item.num,
                                                 operation=outcome_operation,
                                                 production_operation=launch_operations_item.operation,
+                                                color=launch_operations_item.color,
                                                 creator=user,
                                                 qty=launch_operations_item.qty,
                                             )
@@ -378,7 +383,7 @@ class Routing_ext:
                                             operation_value = Operation_value.objects.create(
                                                 operation=outcome_operation,
                                                 value=qty_per_one,
-                                                edizm_id=edizm_id,
+                                                edizm_id=edizm_id if edizm_id != None else edizm_shtuka.id,
                                                 props=Operation_value.props.perone
                                             )
                                             logger.debug(f'Created operation_value :  {operation_value}')
@@ -386,7 +391,7 @@ class Routing_ext:
                                             operation_value = Operation_value.objects.create(
                                                 operation=outcome_operation,
                                                 value=qty,
-                                                edizm_id=edizm_id
+                                                edizm_id=edizm_id if edizm_id != None else edizm_shtuka.id,
                                             )
                                             logger.debug(f'Created operation_value :  {operation_value}')
 
@@ -415,6 +420,7 @@ class Routing_ext:
                                                 operation_resources = Operation_resources.objects.create(
                                                     operation=outcome_operation,
                                                     resource=launch_operation_resources.resource,
+                                                    resource_fin=launch_operation_resources.resource_fin,
                                                     location_fin=launch_operation_resources.location_fin
                                                 )
                                                 logger.debug(f'Created operation_resources :  {operation_resources}')
@@ -426,6 +432,7 @@ class Routing_ext:
                                                 parent=income_operation,
                                                 child=outcome_operation,
                                                 props=Operation_refs.props.inner_routing,
+                                                enable_parent_None=True
                                             )
                                             logger.debug(f'Created operation_refs :  {operation_refs}')
 
@@ -452,7 +459,7 @@ class Routing_ext:
 
                             if progress.step() != 0:
                                 settings.LOCKS.release(key)
-                                WebSocket.full_refresh_grid(grid_id=settings.GRID_CONSTANTS.refresh_production_launch_grid)
+                                Launches_viewManager.fullRows()
                                 raise ProgressDroped(progress_deleted)
 
                         # Выполняем маршрутизацию между товарными позициями соединяя последнюю оперцию предыдущей товарной позиции с первой операциеей следующей
@@ -466,7 +473,7 @@ class Routing_ext:
                                     parent_id = child_id
                                 parent_item = routed_items.find_one(lambda item: item.item_id == parent_id)
                             except StackElementNotExist:
-                                message = f'Товарная позиция не обнаружена среди товарных позиций, прошедших внутреннюю маршрутизацию. Запустите анализатор готовности,и проверьте какая-то сборочная еденица стоит в разделе документации.'
+                                message = 'Товарная позиция не обнаружена среди товарных позиций, прошедших внутреннюю маршрутизацию. Запустите анализатор готовности,и проверьте какая-то сборочная Единица стоит в разделе документации.'
                                 mess2 = ''
                                 operation_item_add = Operation_item_add.objects.filter(item_id=child_id)
                                 if operation_item_add.count() > 0:
@@ -504,8 +511,7 @@ class Routing_ext:
                         f'<h3>Выполнен Расчет маршрутизации: Запуск № {launch.code} от {DateToStr(launch.date)}</h3><p/>'
                     )
 
-                    WebSocket.row_refresh_grid(grid_id=settings.GRID_CONSTANTS.refresh_production_launch_grid_row, records=LaunchesManager.getRecord(launch))
-
+                    Launches_viewManager.refreshRows(ids=launch.id)
                     settings.LOCKS.release(key)
                     drop_mat_view(mat_view_name)
 
@@ -516,13 +522,7 @@ class Routing_ext:
                             launche_head.save()
 
                             # print(LaunchesManager.getRecord(launche_head))
-                            WebSocket.row_refresh_grid(
-                                grid_id=settings.GRID_CONSTANTS.refresh_production_launch_grid_row,
-                                records=LaunchesManager.getRecord(launche_head)
-                            )
-
-        # if idx == launch_qty:
-        #     refresh_mat_view('planing_production_order_mview')
+                            Launches_viewManager.refreshRows(ids=launche_head.id)
 
         return model_to_dict(launch_res)
 
@@ -556,6 +556,7 @@ class Routing_ext:
             operation_resource, created = Operation_resources.objects.update_or_create(
                 operation=new_operation,
                 resource=launch_operation_resource.resource,
+                resource_fin=launch_operation_resource.resource_fin,
                 location_fin=launch_operation_resource.location_fin,
             )
 
@@ -636,23 +637,32 @@ class Routing_ext:
             raise Exception('Оба параметра не могут быть пустыми')
 
         if num != None:
-            launch_operations_item = Launch_operations_item.objects.get(
+            launch_operations_item_query = Launch_operations_item.objects.filter(
                 launch=launch,
                 item=item,
                 num=num,
+                deleted_at=None
             )
         elif old_num != None:
-            launch_operations_item = Launch_operations_item.objects.get(
+            launch_operations_item_query = Launch_operations_item.objects.filter(
                 launch=launch,
                 item=item,
                 old_num=old_num,
+                deleted_at=None
             )
 
+        if launch_operations_item_query.count() > 1:
+            launch_operations_item = launch_operations_item_query[0]
+        elif launch_operations_item_query.count() == 1:
+            launch_operations_item = launch_operations_item_query[0]
+        else:
+            raise Exception('launch_operations_item not found')
+
         operation = Operation_launch_item.objects.get(launch_item=launch_operations_item).operation
         logger.debug(f'operation: {operation}')
         return operation
 
-    def change_parent(self, new_parents, operation,user):
+    def change_parent(self, new_parents, operation, user):
         from kaf_pas.planing.models.operation_refs import Operation_refs
         from kaf_pas.planing.operation_typesStack import RT_TSK
 
@@ -668,8 +678,7 @@ class Routing_ext:
                     logger.debug(f'created new_operation_ref.parent: {operation_ref.parent.id if operation_ref.parent else None}, new_operation_ref.child: {operation_ref.child.id}')
                 else:
                     if operation_ref.deleted_at != None:
-                        operation_ref.deleted_at = None
-                        operation_ref.save()
+                        operation_ref.soft_restore()
 
     def change_childs(self, new_childs, operation, user):
         from kaf_pas.planing.models.operation_refs import Operation_refs
@@ -687,8 +696,7 @@ class Routing_ext:
                     logger.debug(f'created new_operation_ref.parent: {operation_ref.parent.id if operation_ref.parent else None}, new_operation_ref.child: {operation_ref.child.id}')
                 else:
                     if operation_ref.deleted_at != None:
-                        operation_ref.deleted_at = None
-                        operation_ref.save()
+                        operation_ref.soft_restore()
 
     def update_routing(self, data, old_data, updated_launch_operations_items: Stack, user, key=None):
         from kaf_pas.planing.models.operation_launch_item import Operation_launch_item
@@ -722,17 +730,19 @@ class Routing_ext:
 
                 if updated_launch_operations_item.num == updated_launch_operations_item.old_num and not updated_launch_operations_item.is_created:
                     step += 1
-                    # if step >= max_num:
-                    #     self.print_operation_block(launch_id=launch_id, item_id=updated_launch_operations_item.item_id)
+                    if step >= max_num:
+                        self.print_operation_block(launch_id=launch_id, item_id=updated_launch_operations_item.item_id)
+                        pass
                     continue
 
                 logger.debug(f'updated_launch_operations_item.num: {updated_launch_operations_item.num}')
                 logger.debug(f'updated_launch_operations_item.old_num: {updated_launch_operations_item.old_num}')
+
                 if not been_is_created:
                     been_is_created = updated_launch_operations_item.is_created
 
                 if updated_launch_operations_item.num == 1:
-                    if data.production_operation_num < old_data.production_operation_num:
+                    if old_data != None and data.production_operation_num < old_data.production_operation_num:
                         prev_num_operation = self.get_num_operation(
                             launch=updated_launch_operations_item.launch,
                             item=updated_launch_operations_item.item,
@@ -742,7 +752,7 @@ class Routing_ext:
                         prev_num_operation = self.get_num_operation(
                             launch=updated_launch_operations_item.launch,
                             item=updated_launch_operations_item.item,
-                            old_num=old_data.production_operation_num
+                            old_num=old_data.production_operation_num if old_data != None else updated_launch_operations_item.num
                         )
                     parents = self.get_parents(operation=prev_num_operation)
                 else:
@@ -783,8 +793,8 @@ class Routing_ext:
                 # childs = self.get_childs(operation=new_operation)
 
                 if step >= max_num:
+                    self.print_operation_block(launch_id=launch_id, item_id=updated_launch_operations_item.item_id)
                     pass
-                    # self.print_operation_block(launch_id=launch_id, item_id=updated_launch_operations_item.item_id)
                 step += 1
 
     def clean_routing(self, data):
@@ -795,32 +805,40 @@ class Routing_ext:
         from isc_common.progress import managed_progress
         from isc_common.progress import progress_deleted
         from isc_common.progress import ProgressDroped
-        from isc_common.ws.webSocket import WebSocket
         from kaf_pas.planing.models.operation_launches import Operation_launches
         from kaf_pas.planing.models.operations import OperationsManager
         from kaf_pas.production.models.launches import Launches
-        from kaf_pas.production.models.launches import LaunchesManager
-        from kaf_pas.production.models.launches_view import Launches_view
+        from kaf_pas.production.models.launches_view import Launches_viewManager
+        from isc_common.auth.models.user import User
 
         launch_ids = []
         launches_head = []
+
+        if not isinstance(data.get('data'), list):
+            raise Exception('data must be list')
+
         for launch_id in data.get('data'):
-            l = Launches.objects.filter(parent_id=launch_id)
-            if l.count() > 0:
-                launch_ids.extend([item.id for item in l])
+            launches = Launches.objects.filter(parent_id=launch_id)
+            if launches.count() > 0:
+                launch_ids.extend([item.id for item in launches])
                 launches_head.append(Launches.objects.get(id=launch_id))
             else:
                 launch_ids.extend([item.id for item in Launches.objects.filter(id=launch_id)])
 
-        _launch = None
         launch_query = Launches.objects.filter(id__in=launch_ids)
         launch_qty = launch_query.count()
         idx = 0
+
         for launch in launch_query:
-            if launch.status.code == 'formirovanie':
-                continue
+            # if launch.status.code == 'formirovanie':
+            #     continue
 
             user = data.get('user')
+            if isinstance(user, int):
+                user = User.objects.get(id=user)
+            elif not isinstance(user, User):
+                raise Exception('user must be int or User')
+
             key = f'OperationsManager.clean_routing_{launch.id}'
             settings.LOCKS.acquire(key)
             query = Operation_launches.objects.filter(launch=launch, operation__opertype__in=[
@@ -854,29 +872,23 @@ class Routing_ext:
 
                         if progress.step() != 0:
                             settings.LOCKS.release(key)
-                            WebSocket.full_refresh_grid(grid_id=settings.GRID_CONSTANTS.refresh_production_launch_grid)
+
+                            Launches_viewManager.fullRows()
                             raise ProgressDroped(progress_deleted)
 
                     if cnt > 0:
+                        Launches_viewManager.refreshRows(ids=launch.id)
                         settings.EVENT_STACK.EVENTS_PRODUCTION_DELETE_ROUTING.send_message(f'<h3>Выполнено Удаление маршрутизации: Запуск № {launch.code} от {DateToStr(launch.date)}</h3><p/>')
 
                     settings.LOCKS.release(key)
 
                     idx += 1
 
-                    WebSocket.row_refresh_grid(
-                        grid_id=settings.GRID_CONSTANTS.refresh_production_launch_grid_row,
-                        records=LaunchesManager.getRecord(Launches_view.objects.get(id=launch.id))
-                    )
-
                     if idx == launch_qty:
                         for launche_head in launches_head:
                             launche_head.status = settings.PROD_OPERS_STACK.FORMIROVANIE
                             launche_head.save()
 
-                            WebSocket.row_refresh_grid(
-                                grid_id=settings.GRID_CONSTANTS.refresh_production_launch_grid_row,
-                                records=LaunchesManager.getRecord(Launches_view.objects.get(id=launche_head.id))
-                            )
+                            Launches_viewManager.refreshRows(ids=launche_head.id)
 
                         return dict()
