@@ -8,6 +8,7 @@ from isc_common.fields.name_field import NameField
 from isc_common.fields.related import ForeignKeyProtect, ForeignKeyCascade, ForeignKeySetNull
 from isc_common.http.DSRequest import DSRequest
 from isc_common.models.audit import AuditModel, AuditManager, AuditQuerySet
+from isc_common.models.standard_colors import Standard_colors
 from isc_common.number import DelProps, DecimalToStr
 from kaf_pas.ckk.models.ed_izm import Ed_izm
 from kaf_pas.ckk.models.item import Item_add, Item
@@ -22,8 +23,14 @@ logger = logging.getLogger(__name__)
 class Launch_item_line_viewQuerySet(AuditQuerySet):
     def get_range_rows1(self, request, function=None, distinct_field_names=None, remove_fields=None):
         request = DSRequest(request=request)
+
+        # Необходимо в производственной спецификации
         data = request.get_data()
-        delAttr(data, 'launch_id')
+        launch_id = data.get('launch_id')
+        if launch_id != None:
+            launch = Launches.objects.get(id=launch_id)
+            child_launches = launch.child_launches
+            setAttr(data, 'launch_id', list(map(lambda x: x.id, child_launches)) if len(child_launches) > 0 else [launch.id])
 
         request.set_data(data)
 
@@ -71,6 +78,7 @@ class Launch_item_line_viewQuerySet(AuditQuerySet):
         cnt_all = super().filter().count()
         return dict(qty_rows=cnt, all_rows=cnt_all)
 
+
 class Launch_item_line_viewManager(AuditManager):
 
     @staticmethod
@@ -117,6 +125,9 @@ class Launch_item_line_viewManager(AuditManager):
             'SPC_CLM_ZONE_id': record.SPC_CLM_ZONE.id if record.SPC_CLM_ZONE else None,
             'subsection': record.subsection,
             'where_from': record.where_from,
+            'color_id': record.color.id if record.color and record.color else None,
+            'color__name': record.color.name if record.color and record.color else None,
+            'color__color': record.color.color if record.color and record.color else None,
         }
         return DelProps(res)
 
@@ -163,7 +174,7 @@ class Launch_item_line_viewManager(AuditManager):
                 setAttr(_data, key, val)
 
         with transaction.atomic():
-            res = super().filter(id=id).update(**_data)
+            super().filter(id=id).update(**_data)
             Item.objects.update_or_create(id=child_id, defaults=dict(props=item_props))
         return data_res
 
@@ -175,6 +186,8 @@ class Launch_item_line_viewManager(AuditManager):
             for id, mode in tuple_ids:
                 if mode == 'hide':
                     super().filter(id=id).soft_delete()
+                elif mode == 'visible':
+                    super().filter(id=id).soft_restore()
                 else:
                     Launch_item_viewManager.check_launch(launch=Launch_item_line_view.objects.get(id=id).launch)
                     qty, _ = super().filter(id=id).delete()
@@ -200,12 +213,13 @@ class Launch_item_line_view(AuditModel):
     SPC_CLM_USER = ForeignKeyProtect(Document_attributes, verbose_name='Пользовательская', related_name='SPC_CLM_USER_l', null=True, blank=True)
     SPC_CLM_KOD = ForeignKeyProtect(Document_attributes, verbose_name='Код', related_name='SPC_CLM_KOD_l', null=True, blank=True)
     SPC_CLM_FACTORY = ForeignKeyProtect(Document_attributes, verbose_name='Предприятие - изготовитель', related_name='SPC_CLM_FACTORY_l', null=True, blank=True)
-    edizm = ForeignKeyProtect(Ed_izm, verbose_name='Еденица измерения', related_name='EdIzm_l', null=True, blank=True)
+    edizm = ForeignKeyProtect(Ed_izm, verbose_name='Единица измерения', related_name='EdIzm_l', null=True, blank=True)
     section = NameField()
     section_num = PositiveIntegerField(default=0)
     subsection = NameField()
     item_line = ForeignKeySetNull(Item_line, null=True, blank=True)
-    # launch = ForeignKeyProtect(Launches)
+    launch = ForeignKeyProtect(Launches)
+    color = ForeignKeyProtect(Standard_colors, null=True, blank=True)
 
     qty_doc = DecimalField(decimal_places=4, max_digits=19)
     qty_per_one = DecimalField(decimal_places=4, max_digits=19)
