@@ -1,10 +1,10 @@
 import logging
 
 from bitfield import BitField
-from django.contrib.postgres.fields import JSONField
 from django.db.models import CheckConstraint, Q, F, UniqueConstraint, TextField, DecimalField, PositiveIntegerField
 
-from isc_common.fields.related import ForeignKeyProtect, ForeignKeySetNull
+from isc_common.fields.code_field import JSONFieldIVC
+from isc_common.fields.related import ForeignKeyProtect
 from isc_common.models.audit import AuditModel, AuditManager, AuditQuerySet
 from isc_common.models.tree_audit import TreeAuditModelManager
 from isc_common.number import DelProps
@@ -46,7 +46,7 @@ class Launch_item_refsManager(AuditManager):
 class Launch_item_refs(AuditModel):
     child = ForeignKeyProtect(Item, related_name='launch_child')
     item_full_name = TextField(db_index=True)
-    item_full_name_obj = JSONField(default=dict)
+    item_full_name_obj = JSONFieldIVC(default=dict)
     item_refs = ForeignKeyProtect(Item_refs, blank=True, null=True)
     launch = ForeignKeyProtect(Launches)
     parent = ForeignKeyProtect(Item, related_name='launch_parent', blank=True, null=True)
@@ -75,6 +75,6 @@ class Launch_item_refs(AuditModel):
         verbose_name = 'Древо производственной спецификации'
         constraints = [
             CheckConstraint(check=~Q(child=F('parent')), name='Launch_item_refs_not_circulate_refs'),
-            UniqueConstraint(fields=['child_id', 'launch_id', 'props', 'qty', 'qty_per_one'], condition=Q(parent_id=None), name='Launch_item_refs_unique_constraint_0'),
-            UniqueConstraint(fields=['child_id', 'launch_id', 'parent_id', 'props', 'qty', 'qty_per_one'], name='Launch_item_refs_unique_constraint_1'),
+            UniqueConstraint(fields=['child', 'launch'], condition=Q(parent=None), name='Launch_item_refs_unique_constraint_0'),
+            UniqueConstraint(fields=['child', 'launch', 'parent'], name='Launch_item_refs_unique_constraint_1'),
         ]
