@@ -8,14 +8,14 @@ from django.forms import model_to_dict
 
 from isc_common import delAttr, setAttr
 from isc_common.bit import IsBitOn
-from isc_common.fields.related import ForeignKeyProtect
+from isc_common.fields.related import ForeignKeyProtect, ForeignKeySetNull
 from isc_common.http.DSRequest import DSRequest
 from isc_common.managers.common_managet_with_lookup_fields import CommonManagetWithLookUpFieldsManager, CommonManagetWithLookUpFieldsQuerySet
 from isc_common.models.audit import AuditModel
 from isc_common.number import DelProps
 from kaf_pas.ckk.models.locations import Locations
 from kaf_pas.production.models.launch_operations_item import Launch_operations_item
-from kaf_pas.production.models.operation_resources import Operation_resources
+from kaf_pas.production.models.operation_resources import Operation_resources, OR_Wrapper
 from kaf_pas.production.models.resource import Resource
 
 logger = logging.getLogger(__name__)
@@ -27,12 +27,21 @@ class Launch_operation_resourcesQuerySet(CommonManagetWithLookUpFieldsQuerySet):
             setAttr(kwargs, 'resource_id', kwargs.get('resource').id)
             delAttr(kwargs, 'resource')
 
+        if kwargs.get('resource'):
+            setAttr(kwargs, 'resource_fin_id', kwargs.get('resource_fin').id)
+            delAttr(kwargs, 'resource_fin')
+
         if kwargs.get('location'):
             setAttr(kwargs, 'location_id', kwargs.get('location').id)
             delAttr(kwargs, 'location')
 
+        if kwargs.get('location_fin'):
+            setAttr(kwargs, 'location_fin_id', kwargs.get('location_fin').id)
+            delAttr(kwargs, 'location_fin')
+
         if not kwargs.get('resource_id') and not kwargs.get('location_id'):
             raise Exception('Необходим хотябы один выбранный параметр.')
+
         delAttr(kwargs, 'resource__name')
         delAttr(kwargs, 'location__full_name')
 
@@ -55,7 +64,7 @@ class Launch_operation_resourcesManager(CommonManagetWithLookUpFieldsManager):
                 group by launch_operationitem_id
                 having count(*) > 1'''
 
-        sql_items = f'''select id
+        sql_items = '''select id
         from production_launch_operation_resources
         where launch_operationitem_id = %s'''
 
@@ -74,7 +83,7 @@ class Launch_operation_resourcesManager(CommonManagetWithLookUpFieldsManager):
                         id, = item
                         if not first_step:
                             # print(f'id: {id}')
-                            res = Launch_operation_resources.objects.filter(id=id).delete()
+                            Launch_operation_resources.objects.filter(id=id).delete()
                             # print(res)
                         else:
                             first_step = False
@@ -85,7 +94,17 @@ class Launch_operation_resourcesManager(CommonManagetWithLookUpFieldsManager):
 
         request = DSRequest(request=request)
         data = request.get_data()
-        _data = data.copy()
+
+        _data = OR_Wrapper(**data)
+
+        if _data.resource_id:
+            _data.location_id = Resource.objects.get(id=_data.resource_id).location.id
+
+        if _data.resource_fin_id:
+            _data.location_fin_id = Resource.objects.get(id=_data.resource_fin_id).location.id
+
+        _data = self.delete_dbl_underscore_element(_data.dict)
+
         launch_operationitem_id = _data.get('launch_operationitem_id')
 
         res = []
@@ -99,17 +118,42 @@ class Launch_operation_resourcesManager(CommonManagetWithLookUpFieldsManager):
                     operation_resource = super().create(**_data)
                     _res = model_to_dict(operation_resource)
                     setAttr(_res, 'location__full_name', operation_resource.location.full_name if operation_resource.location else None)
+                    setAttr(_res, 'location_fin__full_name', operation_resource.location_fin.full_name if operation_resource.location_fin else None)
                     setAttr(_res, 'resource__name', operation_resource.resource.full_name if operation_resource.resource else None)
+                    setAttr(_res, 'resource_fin__name', operation_resource.resource_fin.full_name if operation_resource.resource_fin else None)
                     res.append(DelProps(_res))
         else:
             Launch_item_viewManager.check_launch(Launch_operation_resources.objects.get(launch_operationitem_id=launch_operationitem_id).launch_operationitem.launch)
             operation_resource = super().create(**_data)
             _res = model_to_dict(operation_resource)
             setAttr(_res, 'location__full_name', operation_resource.location.full_name if operation_resource.location else None)
-            setAttr(_res, 'resource__name', operation_resource.resource.full_name if operation_resource.resource else None)
+            setAttr(_res, 'location_fin__full_name', operation_resource.location_fin.full_name if operation_resource.location_fin else None)
+            setAttr(_res, 'resource_fin__name', operation_resource.resource.full_name if operation_resource.resource else None)
+            setAttr(_res, 'resource_fin__name', operation_resource.resource_fin.full_name if operation_resource.resource_fin else None)
             res.append(DelProps(_res))
         return res
 
+    def updateFromRequest(self, request, removed=None, function=None):
+        if not isinstance(request, DSRequest):
+            request = DSRequest(request=request)
+        data = request.get_data()
+
+        self._remove_prop(data, removed)
+        _data = OR_Wrapper(**data)
+
+        if _data.resource_id:
+            _data.location_id = Resource.objects.get(id=_data.resource_id).location.id
+
+        if _data.resource_fin_id:
+            _data.location_fin_id = Resource.objects.get(id=_data.resource_fin_id).location.id
+
+        _data = self.delete_dbl_underscore_element(_data.dict)
+
+        delAttr(_data, 'id')
+        delAttr(_data, 'complex_name')
+        res = super().filter(id=data.get('id')).update(**_data)
+        return res
+
     def deleteFromRequest(self, request, removed=None, ):
         from kaf_pas.production.models.launch_item_view import Launch_item_viewManager
 
@@ -120,6 +164,8 @@ class Launch_operation_resourcesManager(CommonManagetWithLookUpFieldsManager):
             for id, mode in tuple_ids:
                 if mode == 'hide':
                     super().filter(id=id).soft_delete()
+                elif mode == 'visible':
+                    super().filter(id=id).soft_restore()
                 else:
                     Launch_item_viewManager.check_launch(Launch_operation_resources.objects.get(id=id).launch_operationitem.launch)
                     qty, _ = super().filter(id=id).delete()
@@ -135,6 +181,9 @@ class Launch_operation_resourcesManager(CommonManagetWithLookUpFieldsManager):
             'resource_id': record.resource.id if record.resource else None,
             'resource__code': record.resource.code if record.resource else None,
             'resource__name': record.resource.name if record.resource else None,
+            'resource_fin_id': record.resource_fin.id if record.resource_fin else None,
+            'resource_fin__code': record.resource_fin.code if record.resource_fin else None,
+            'resource_fin__name': record.resource_fin.name if record.resource_fin else None,
             'location_id': record.location.id if record.location else None,
             'location__code': record.location.code if record.location else None,
             'location__name': record.location.name if record.location else None,
@@ -157,12 +206,13 @@ class Launch_operation_resourcesManager(CommonManagetWithLookUpFieldsManager):
 
 
 class Launch_operation_resources(AuditModel):
-    operation_resources = ForeignKeyProtect(Operation_resources, null=True, blank=True)
+    batch_size = PositiveIntegerField(default=1, db_index=True)
     launch_operationitem = OneToOneField(Launch_operations_item, on_delete=CASCADE)
-    resource = ForeignKeyProtect(Resource, null=True, blank=True)
     location = ForeignKeyProtect(Locations, related_name='Launch_operation_resources_location')
     location_fin = ForeignKeyProtect(Locations, related_name='Launch_operation_resources_location_fin', null=True, blank=True)
-    batch_size = PositiveIntegerField(default=1, db_index=True)
+    operation_resources = ForeignKeySetNull(Operation_resources, null=True, blank=True)
+    resource = ForeignKeyProtect(Resource, related_name='Launch_operation_resources_resource')
+    resource_fin = ForeignKeyProtect(Resource, related_name='Launch_operation_resources_resource_fin', null=True, blank=True)
 
     props = BitField(flags=(
         ('enabled', 'Доступность в данной производственной спецификации'),  # 1
@@ -186,12 +236,8 @@ class Launch_operation_resources(AuditModel):
     class Meta:
         verbose_name = 'Кросс таблица'
         constraints = [
-            UniqueConstraint(fields=['launch_operationitem'], condition=Q(location=None) & Q(location_fin=None) & Q(resource=None), name='Launch_operation_resources_unique_constraint_0'),
-            UniqueConstraint(fields=['launch_operationitem', 'resource'], condition=Q(location=None) & Q(location_fin=None), name='Launch_operation_resources_unique_constraint_1'),
-            UniqueConstraint(fields=['launch_operationitem', 'location'], condition=Q(location_fin=None) & Q(resource=None), name='Launch_operation_resources_unique_constraint_2'),
-            UniqueConstraint(fields=['launch_operationitem', 'location', 'resource'], condition=Q(location_fin=None), name='Launch_operation_resources_unique_constraint_3'),
-            UniqueConstraint(fields=['launch_operationitem', 'location_fin'], condition=Q(location=None) & Q(resource=None), name='Launch_operation_resources_unique_constraint_4'),
-            UniqueConstraint(fields=['launch_operationitem', 'location_fin', 'resource'], condition=Q(location=None), name='Launch_operation_resources_unique_constraint_5'),
-            UniqueConstraint(fields=['launch_operationitem', 'location', 'location_fin'], condition=Q(resource=None), name='Launch_operation_resources_unique_constraint_6'),
-            UniqueConstraint(fields=['launch_operationitem', 'location', 'location_fin', 'resource'], name='Launch_operation_resources_unique_constraint_7'),
+            UniqueConstraint(fields=['launch_operationitem', 'location', 'resource'], condition=Q(location_fin=None) & Q(resource_fin=None), name='Launch_operation_resources_unique_constraint_0'),
+            UniqueConstraint(fields=['launch_operationitem', 'location', 'resource', 'resource_fin'], condition=Q(location_fin=None), name='Launch_operation_resources_unique_constraint_1'),
+            UniqueConstraint(fields=['launch_operationitem', 'location', 'location_fin', 'resource'], condition=Q(resource_fin=None), name='Launch_operation_resources_unique_constraint_2'),
+            UniqueConstraint(fields=['launch_operationitem', 'location', 'location_fin', 'resource', 'resource_fin'], name='Launch_operation_resources_unique_constraint_3'),
         ]
