@@ -2,15 +2,17 @@ import logging
 
 from bitfield import BitField
 from django.db import transaction
-from django.db.models import PositiveIntegerField
+from django.db.models import PositiveIntegerField, UniqueConstraint, Q
 from django.forms import model_to_dict
 
 from isc_common import delAttr, setAttr
+from isc_common.bit import IsBitOn
 from isc_common.fields.description_field import DescriptionField
-from isc_common.fields.related import ForeignKeyProtect
+from isc_common.fields.related import ForeignKeyProtect, ForeignKeySetNull
 from isc_common.http.DSRequest import DSRequest
 from isc_common.managers.common_managet_with_lookup_fields import CommonManagetWithLookUpFieldsQuerySet, CommonManagetWithLookUpFieldsManager
 from isc_common.models.base_ref import Hierarcy
+from isc_common.models.standard_colors import Standard_colors
 from isc_common.number import DelProps
 from kaf_pas.ckk.models.ed_izm import Ed_izm
 from kaf_pas.ckk.models.item import Item
@@ -24,11 +26,15 @@ logger = logging.getLogger(__name__)
 
 class Launch_operations_itemQuerySet(CommonManagetWithLookUpFieldsQuerySet):
     def create(self, **kwargs):
+        self._check_ed_izm_qty(**kwargs)
+
         if kwargs.get('props') == None:
             setAttr(kwargs, 'props', Launch_operations_item.props.created)
         return super().create(**kwargs)
 
     def update(self, **kwargs):
+        self._check_ed_izm_qty(**kwargs)
+
         if kwargs.get('props') == None:
             setAttr(kwargs, 'props', Launch_operations_item.props.updated)
         return super().update(**kwargs)
@@ -92,6 +98,11 @@ class Launch_operations_itemManager(CommonManagetWithLookUpFieldsManager):
             'parent_id': record.parent.id if record.parent else None,
             'editing': record.editing,
             'deliting': record.deliting,
+            'isDeleted': record.is_deleted,
+
+            'color__color': record.color.color if record.color else None,
+            'color__name': record.color.name if record.color else None,
+            'color_id': record.color.id if record.color else None,
         }
         return res
 
@@ -151,13 +162,41 @@ class Launch_operations_itemManager(CommonManagetWithLookUpFieldsManager):
     def updateFromRequest(self, request, removed=None, function=None):
         request = DSRequest(request=request)
         data = request.get_data()
+
         Launch_item_viewManager.check_launch(launch=Launches.objects.get(id=data.get('launch_id')))
+
+        # Скопирование с технологички , как пример
+        # Выравниваем нумерацию ели изменен порядок следования операций
+        # operation_item = Operations_item.objects.get(id=data.id)
+        # operations_item = list(Operations_item.objects.filter(item=operation_item.item, deleted_at=None).order_by('num'))
+        #
+        # if data.num != data_old.num:
+        #
+        #     operations_item = list(Operations_item.objects.filter(item=operation_item.item, deleted_at=None).order_by('num').exclude(id=operation_item.id))
+        #
+        #     num = 1
+        #     for oi in operations_item:
+        #         oi.num = num
+        #         oi.save()
+        #         num += 1
+        #
+        #     if data.num >= len(operations_item):
+        #         operations_item.append(operation_item)
+        #     else:
+        #         operations_item.insert(data.num - 1, operation_item)
+        #
+        #     num = 1
+        #     for oi in operations_item:
+        #         oi.num = num
+        #         oi.save()
+        #         num += 1
+
         _data = data.copy()
 
         delAttr(_data, 'operation__full_name')
         delAttr(_data, 'enabled')
         delAttr(_data, 'id')
-        res = super().filter(id=data.get('id')).update(**_data)
+        super().filter(id=data.get('id')).update(**_data)
 
         return data
 
@@ -169,22 +208,27 @@ class Launch_operations_itemManager(CommonManagetWithLookUpFieldsManager):
             for id, mode in tuple_ids:
                 if mode == 'hide':
                     super().filter(id=id).soft_delete()
-                else:
+                elif mode == 'visible':
+                    super().filter(id=id).soft_restore()
+                elif mode == None:
                     Launch_item_viewManager.check_launch(launch=Launch_operations_item.objects.get(id=id).launch)
                     qty, _ = super().filter(id=id).delete()
+                else:
+                    raise Exception(f'{mode} is not clear situation.')
                 res += qty
         return res
 
 
 class Launch_operations_item(Hierarcy):
+    color = ForeignKeyProtect(Standard_colors, null=True, blank=True)
     description = DescriptionField()
     ed_izm = ForeignKeyProtect(Ed_izm, null=True, blank=True)
     item = ForeignKeyProtect(Item)
     launch = ForeignKeyProtect(Launches)
-    num = PositiveIntegerField(db_index=True, default=None)
+    num = PositiveIntegerField(db_index=True)
     old_num = PositiveIntegerField(db_index=True, null=True, blank=True)
     operation = ForeignKeyProtect(Operations)
-    operationitem = ForeignKeyProtect(Operations_item)
+    operationitem = ForeignKeySetNull(Operations_item, null=True, blank=True)
     props = Launch_operations_itemManager.props()
     qty = PositiveIntegerField(null=True, blank=True, db_index=True)
 
@@ -192,14 +236,17 @@ class Launch_operations_item(Hierarcy):
 
     def __str__(self):
         return f"ID:{self.id}, " \
+               f"is_deleted: {self.is_deleted}, " \
                f"old_num: {self.old_num}, " \
                f"num: {self.num}, " \
+               f"color: {self.color}, " \
+               f"deleted_at: {self.deleted_at}, " \
+               f"launch: [{self.launch}], " \
                f"operation: [{self.operation}], " \
                f"operationitem: [{self.operationitem}], " \
                f"qty: {self.qty}, " \
                f"props: {self.props}"
 
-
         # return f"ID:{self.id}, \n" \
         #        f"item: [{self.item}], \n" \
         #        f"id_izm: [{self.ed_izm}], \n" \
@@ -216,12 +263,19 @@ class Launch_operations_item(Hierarcy):
 
     @property
     def is_created(self):
-        return self.props._value == Launch_operations_item.props.created
+        return IsBitOn(self.props, Launch_operations_item.props.created)
 
     @property
     def is_updated(self):
-        return self.props._value == Launch_operations_item.props.updated
+        return IsBitOn(self.props, Launch_operations_item.props.updated)
 
     class Meta:
         verbose_name = 'Кросс таблица'
-        unique_together = (('item', 'launch', 'operation', 'num', 'operationitem'),)
+        constraints = [
+            UniqueConstraint(fields=['item', 'launch', 'operation'], condition=Q(color=None) & Q(operationitem=None), name='Launch_operations_item_unique_constraint_0'),
+            UniqueConstraint(fields=['color', 'item', 'launch', 'operation'], condition=Q(operationitem=None), name='Launch_operations_item_unique_constraint_1'),
+            UniqueConstraint(fields=['item', 'launch', 'operation', 'operationitem'], condition=Q(color=None), name='Launch_operations_item_unique_constraint_2'),
+            UniqueConstraint(fields=['color', 'item', 'launch', 'operation', 'operationitem'], name='Launch_operations_item_unique_constraint_3'),
+        ]
+
+
