@@ -2,6 +2,8 @@ import logging
 
 from bitfield import BitField
 
+from isc_common.bit import IsBitOn
+from isc_common.fields.code_field import CodeStrictField
 from isc_common.fields.name_field import NameStrictField
 from isc_common.managers.common_managet_with_lookup_fields import CommonManagetWithLookUpFieldsManager, CommonManagetWithLookUpFieldsQuerySet
 from isc_common.models.base_ref import BaseRefHierarcy, BaseRefQuerySet
@@ -19,19 +21,20 @@ class OperationsManager(CommonManagetWithLookUpFieldsManager):
     @staticmethod
     def getRecord(record):
         res = {
-            'id': record.id,
+            'absorption': record.props.absorption,
             'code': record.code,
-            'name': record.name,
-            'full_name': record.full_name,
-            'description': record.description,
-            'parent_id': record.parent_id,
-            'lastmodified': record.lastmodified,
-            'editing': record.editing,
             'deliting': record.deliting,
+            'description': record.description,
+            'editing': record.editing,
+            'full_name': record.full_name,
+            'id': record.id,
+            'lastmodified': record.lastmodified,
+            'launched': record.props.launched,
+            'name': record.name,
+            'parent_id': record.parent_id,
+            # 'partition_to_launch': record.props.partition_to_launch,
             'props': record.props,
-            'assemly': record.props.assemly,
             'transportation': record.props.transportation,
-            'made_common_form': record.props.made_common_form,
         }
         return DelProps(res)
 
@@ -41,13 +44,15 @@ class OperationsManager(CommonManagetWithLookUpFieldsManager):
     @staticmethod
     def get_props():
         return BitField(flags=(
-            ('assemly', 'Операция комплектации'),  # 1
-            ('made_common_form', 'Формировать общий документ'),  # 2
-            ('transportation', 'Операция транспортировки'),  # 4
+            ('launched', 'Возможность привязки к запуску'),  # 0
+            ('no_used', 'Не используется'),  # 1
+            ('transportation', 'Операция транспортировки'),  # 2
+            ('absorption', 'Операция поглощения'),  # 3
         ), default=0, db_index=True)
 
 
 class Operations(BaseRefHierarcy):
+    code = CodeStrictField(unique=True)
     name = NameStrictField()
     props = OperationsManager.get_props()
 
@@ -56,10 +61,30 @@ class Operations(BaseRefHierarcy):
         from kaf_pas.production.models.operation_attr import Operation_attr
         return [item.attr_type.code for item in Operation_attr.objects.filter(operation=self)]
 
+    @property
+    def is_launched(self):
+        return IsBitOn(self.props, Operations.props.launched)
+        # return True
+
+    # @property
+    # def is_partition_to_launch(self):
+    #     return IsBitOn(self.props, Operations.props.partition_to_launch)
+
+    @property
+    def is_transportation(self):
+        return IsBitOn(self.props, Operations.props.transportation)
+
+    @property
+    def is_absorption(self):
+        return IsBitOn(self.props, Operations.props.absorption)
+
     objects = OperationsManager()
 
     def __str__(self):
-        return f'ID={self.id}, code={self.code}, name={self.name}, full_name={self.full_name}, description={self.description}'
+        return f'ID={self.id}, code={self.code}, name={self.name} , props={self.props} , description={self.description}'
 
     class Meta:
         verbose_name = 'Операции'
+        db_constraints = {
+            'Operations_not_cycled': 'CHECK ("id" != "parent_id")',
+        }
