@@ -1,8 +1,8 @@
 import logging
 
-from django.contrib.postgres.fields import JSONField
 from django.db.models import TextField
 
+from isc_common.fields.code_field import JSONFieldIVC
 from isc_common.fields.related import ForeignKeyCascade
 from isc_common.models.audit import AuditModel, AuditManager, AuditQuerySet
 from kaf_pas.production.models.ready_2_launch import Ready_2_launch
@@ -37,7 +37,7 @@ class Ready_2_launch_detailManager(AuditManager):
 class Ready_2_launch_detail(AuditModel):
     ready = ForeignKeyCascade(Ready_2_launch)
     item_full_name = TextField(null=True, blank=True)
-    item_full_name_obj = JSONField(default=dict)
+    item_full_name_obj = JSONFieldIVC(default=dict)
     notes = TextField(null=True, blank=True)
 
     objects = Ready_2_launch_detailManager()
