@@ -5,10 +5,9 @@ from django.db.models import BooleanField
 from clndr.models.calendars import Calendars
 from isc_common.fields.related import ForeignKeyProtect
 from isc_common.managers.common_managet_with_lookup_fields import CommonManagetWithLookUpFieldsQuerySet, CommonManagetWithLookUpFieldsManager
-from isc_common.models.base_ref import BaseRefHierarcy, BaseRef
+from isc_common.models.base_ref import BaseRef
 from isc_common.number import DelProps
 from kaf_pas.ckk.models.locations import Locations
-from kaf_pas.production.models.resource import ResourceManager
 
 logger = logging.getLogger(__name__)
 
