@@ -25,14 +25,19 @@ class Operation_Stack:
                 deliting=False,
             ))
 
-            self.NOT_UNDEFINED_WORKSHOP = lambda location: Resource.objects.get_or_create(
-                location=location,
-                code='none',
-                defaults=dict(
-                    name='Не определен'
-                )
-            )
+            def rec(location):
+                if location != None:
+                    return Resource.objects.get_or_create(
+                        location=location,
+                        code='none',
+                        defaults=dict(
+                            name='Не определен'
+                        )
+                    )
+                else:
+                    return None, False
 
+            self.NOT_UNDEFINED_WORKSHOP = rec
 
         except ProgrammingError as ex:
             logger.warning(ex)
