@@ -17,8 +17,8 @@ def Operations_item_Fetch(request):
         DSResponse(
             request=request,
             data=Operations_item.objects.
-                select_related('item', 'operation', 'ed_izm').
-                distinct().
+                select_related('item', 'operation', 'ed_izm', 'color').
+                order_by('num').
                 get_range_rows1(
                 request=request,
                 function=Operations_itemManager.getRecord
@@ -96,14 +96,18 @@ def Operations_item_CopyOpers(request):
                                 Operation_resources.objects.get_or_create(
                                     operationitem=operations_item,
                                     resource=operation_resources.resource,
-                                    location=operation_resources.location
+                                    resource_fin=operation_resources.resource_fin,
+                                    location=operation_resources.location,
+                                    location_fin=operation_resources.location_fin
                                 )
                         else:
                             for operation_resources in Operation_resources.objects.filter(operationitem=old_operations_item):
                                 Operation_resources.objects.get_or_create(
                                     operationitem=operations_item,
                                     resource=operation_resources.resource,
-                                    location=operation_resources.location
+                                    resource_fin=operation_resources.resource_fin,
+                                    location=operation_resources.location,
+                                    location_fin=operation_resources.location_fin
                                 )
 
                         if source_name == 'templates':
@@ -128,4 +132,4 @@ def Operations_item_CopyOpers(request):
 
         return JsonResponse(DSResponse(request=request, status=RPCResponseConstant.statusSuccess).response)
     else:
-        raise Exception(f'Копирование не выполнено.')
+        raise Exception('Копирование не выполнено.')
