@@ -1,12 +1,13 @@
 import logging
 
-from django.db.models import PositiveIntegerField, DateTimeField, BooleanField, CharField
+from django.db.models import PositiveIntegerField, DateTimeField, BooleanField
 
 from isc_common.bit import IsBitOff
 from isc_common.fields.code_field import CodeField
 from isc_common.fields.related import ForeignKeyProtect, ForeignKeyCascade
 from isc_common.managers.common_managet_with_lookup_fields import CommonManagetWithLookUpFieldsManager, CommonManagetWithLookUpFieldsQuerySet
 from isc_common.models.base_ref import BaseRefHierarcy
+from kaf_pas.kd.models.document_attributes import Document_attributes
 from kaf_pas.sales.models.precent import Precent
 from kaf_pas.sales.models.precent_dogovors import Precent_dogovors
 from kaf_pas.sales.models.precent_items import Precent_items
@@ -140,6 +141,8 @@ class Demand_view(BaseRefHierarcy):
     qty_for_launch = PositiveIntegerField(blank=True, null=True)
     status = ForeignKeyProtect(Status_demand)
     tail_qty = PositiveIntegerField()
+    STMP_1 = ForeignKeyProtect(Document_attributes, related_name='Demand_view_STMP_1', null=True, blank=True)
+    STMP_2 = ForeignKeyProtect(Document_attributes, related_name='Demand_view_STMP_2', null=True, blank=True)
     year = CodeField()
 
     objects = Demand_viewManager()
