@@ -23,6 +23,8 @@ class Precent_dogovorsManager(CommonManagetWithLookUpFieldsManager):
             'dogovor__name': record.dogovor.name,
             'dogovor__full_name': record.dogovor.full_name,
             'dogovor__date': record.dogovor.date,
+            'dogovor__customer_id': record.dogovor.customer.id,
+            'dogovor__customer__name': record.dogovor.customer.name,
             'editing': record.editing,
             'deliting': record.deliting,
             # 'enabled': IsBitOn(record.dogovor.props, 0)
