@@ -1,3 +1,4 @@
+from isc_common.http.DSRequest import DSRequest
 from isc_common.http.DSResponse import DSResponseUpdate, DSResponseAdd, DSResponse, JsonResponseWithException, JsonWSResponseWithException
 from isc_common.http.RPCResponse import RPCResponseConstant
 from isc_common.http.response import JsonResponse
@@ -7,6 +8,7 @@ from kaf_pas.sales.models.demand_view import Demand_view, Demand_viewManager
 
 @JsonResponseWithException()
 def Demand_Fetch(request):
+    _request = DSRequest(request)
     return JsonResponse(
         DSResponse(
             request=request,
@@ -53,7 +55,7 @@ def Demand_Lookup(request):
 
 @JsonResponseWithException()
 def Demand_Info(request):
-    return JsonResponse(DSResponse(request=request, data=Demand.objects.get_queryset().get_info(request=request), status=RPCResponseConstant.statusSuccess).response)
+    return JsonResponse(DSResponse(request=request, data=Demand_view.objects.get_queryset().get_info(request=request), status=RPCResponseConstant.statusSuccess).response)
 
 
 @JsonResponseWithException()
